#
# spec file for package libgsf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgsf
Version:        1.14.53
Release:        1.6
Summary:        I/O library for dealing with structured file formats
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://www.gnome.org
Source:         https://download.gnome.org/sources/libgsf/1.14/%{name}-%{version}.tar.xz
BuildRequires:  intltool
BuildRequires:  libbz2-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0) >= 2.26.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.26.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.26.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.0.0
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4.16
Requires:       libgsf-1-114

%description
The libgsf library is an extensible I/O abstraction library for dealing
with structured file formats.

%package tools
Summary:        Tools from libgsf, a structured file formats handling library
Group:          Productivity/Office/Other

%description tools
The libgsf library is an extensible I/O abstraction library for dealing
with structured file formats.

%package -n gsf-office-thumbnailer
Summary:        Office files thumbnailer for the GNOME desktop
Group:          Productivity/Office/Other

%description -n gsf-office-thumbnailer
This package provides a thumbnailer for office files.

%package 1-114
Summary:        I/O library for dealing with structured file formats
# To make lang package installable
Group:          System/Libraries
Provides:       %{name} = %{version}
# With libgsf 1.14.22 (first in 12.2), gnome-vfs and bonobo support got dropped, so no more gnome package.
Obsoletes:      libgsf-gnome < 1.14.22
# With libgsf 1.14.23 (first in 12.2), we prefer to use introspection
Obsoletes:      python-gsf < 1.14.23
#

%description 1-114
The libgsf library is an extensible I/O abstraction library for dealing
with structured file formats.

%package -n typelib-1_0-Gsf-1
Summary:        Introspection bindings for the GNOME desktop Office files thumbnailer
Group:          System/Libraries

%description -n typelib-1_0-Gsf-1
The libgsf library is an extensible I/O abstraction library for dealing
with structured file formats.

%package devel
Summary:        Development files for libgsf, a structured file format handling library
Group:          Development/Libraries/GNOME
Requires:       libgsf-1-114 = %{version}
Requires:       typelib-1_0-Gsf-1 = %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}
#

%description devel
The libgsf library is an extensible I/O abstraction library for dealing
with structured file formats.

%lang_package

%prep
%setup -q

%build
%configure --disable-static \
        --enable-introspection
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print

%post 1-114 -p /sbin/ldconfig
%postun 1-114 -p /sbin/ldconfig

%files tools
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/gsf
%{_bindir}/gsf-vba-dump
%{_mandir}/man1/gsf.1%{ext_man}
%{_mandir}/man1/gsf-vba-dump.1%{ext_man}

%files -n gsf-office-thumbnailer
%{_bindir}/gsf-office-thumbnailer
%{_mandir}/man1/gsf-office-thumbnailer.1%{ext_man}
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/gsf-office.thumbnailer

%files 1-114
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/libgsf-1.so.*

%files -n typelib-1_0-Gsf-1
%{_libdir}/girepository-1.0/Gsf-1.typelib

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/libgsf-1
%{_datadir}/gir-1.0/Gsf-1.gir
%{_datadir}/gtk-doc/

%files lang -f %{name}.lang

%changelog
* Tue Oct  1 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.53:
  + Compilation fixes for libxml 2.13
  + Fix ABR in gsf-vba-dump.
  + Teach gsf (the tool) to handle odf properties.
  + Fix integer overflows affecting memory allocation.
  + Add missing "DocumentStatus" ole2 property.
  + Avoid some undefined C behaviour in overflow checks.
* Mon Feb  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.14.52:
  + xml: Fix build with libxml2 2.12.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Own /usr/share/gtk-doc: glib no longer uses gtk-doc and as a
  consequence cannot be held responsible to deliver that basic
  directory structure.
* Fri Nov  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop baselibs.conf, nothing should need the 32bit libs anymore.
* Fri Nov  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.51:
  + Fix thumbnailer crash.
  + Fix leaks.
* Wed Aug 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.50:
  + Fix error handling problem when writing ole files.
* Mon Mar 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.49:
  + Use g_date_time_new_from_iso8601 and g_date_time_format_iso8601
    when available.
  + Fix problems with non-western text in OLE properties.
* Tue Dec 28 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.48:
  + Add "zip64" readable property of GsfInfileZip.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Thu Apr 16 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.14.47:
  + GsfOutputMemory improvement.
  + Teach GsfOutputGzip to control compression level.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun May  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.46:
  + Upgrade to newer gettext.
  + Warning fixes.
  + Fix gsf-vba-dump crash.
* Wed Dec 19 2018 bjorn.lie@gmail.com
- Update to version 1.14.45:
  + Fix problem with ole property writing.
* Thu Aug  9 2018 bjorn.lie@gmail.com
- Update to version 1.14.44:
  + Fix msole metadata writing for non-ascii.
  + Fix problem with threaded code.
* Fri Apr 20 2018 bjorn.lie@gmail.com
- Update to version 1.14.43:
  + Handle modtime for memory mapped files.
  + Introspection fixes.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar  5 2018 jengelh@inai.de
- Update summaries. Fix SRPM group.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Nov 12 2017 luc14n0@linuxmail.org
- Update to version 1.14.42:
  + Fix GsfInputTextline's file location management.
  + doc/Makefile.am fix for gtkdoc-scangobj.
- Drop %%clean section as its use is obsolete since RPM do this job
  now.
- Add pkgconfig(gobject-2.0) BuildRequires: it was already being
  used and pulled along with the ever declared pkgconfig(glib-2.0)
  since they live in the same devel package.
- Abreviate packages summaries as they were too long.
* Sat Dec  3 2016 dimstar@opensuse.org
- Update to version 1.14.41:
  + Fix corrupted-tar-file crash.
* Sat Aug 20 2016 zaitor@opensuse.org
- Updated to version 1.14.40:
  + Avoid gnome-common dependency.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Wed Jun 29 2016 zaitor@opensuse.org
- Update to version 1.14.39:
  + Tests: suppressions.
* Sun Jun 19 2016 zaitor@opensuse.org
- Update to version 1.14.38:
  + BSD compatibility for test (bgo#767044).
  + Fix zip64 problem (bgo#767043).
  + Improve testing.
* Mon May 30 2016 zaitor@opensuse.org
- Update to version 1.14.37:
  + Fix tar issue (bgo#765099).
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Sat Feb 13 2016 zaitor@opensuse.org
- Update to version 1.14.36:
  + Fix some criticals.
  + Plug leak.
  + Fix openpkg absolute member reference (bgo#761648).
* Sat Feb  6 2016 zaitor@opensuse.org
- Update to version 1.14.35:
  + Fix OLE2 property writing issue (bgo#760047).
  + Improve handling of broken zip files (bgo#760543).
  + Fix locale handling in thumbnailer (bgo#760428).
  + Updated translations.
* Mon Aug  3 2015 zaitor@opensuse.org
- Update to version 1.14.34:
  + Fix OLE2 property parsing problem (bgo#748528).
  + xlsx: fix problem with absolute relation targets (bgo#751120).
  + Fix text line problem with very long lines.
  + Fuzzed file fixes: bgo#749120, bgo#749169, bgo#749183,
    bgo#750809, bgo#751273.
* Sat Apr 18 2015 zaitor@opensuse.org
- Update to version 1.14.33:
  + Ensure floats roundtrip through our xml functions.
  + Improve handling of unknown xml tags.
  + xml parser improvements.
  + xml pretty-printing improvements.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 1.14.32:
  + Fix obscure problem with xml parser.
  + Add vml to openpkg utils.
  + Allow NULL content type for openpkg.
  + Plug leak.
* Thu Feb  5 2015 dimstar@opensuse.org
- Update to version 1.14.31:
  + Add two new localc name spaces to gsf-opendoc-utils
  + Add support for non-default zip compression level (bgo#722470).
  + Plug leaks.
  + Dead kittens.
  + Reduce number of CRITICALs for corrupted files.
  + Read zip files with 64k+ members (Part of bgo#732209).
  + Read zip files members larger than 4G (Part of bgo#732209).
  + Speed up zip file reading for lots of members.
  + Speed up stdio directory handling with large number of files.
  + Fix various issues with files larger than 4G.
  + Fix minor zip file issues.
  + Write zip archives with more than 64k+ members.
  + Store unix modtime in zip (Until that overflows).
  + Fix seekability checks in GsfOutputIOChannel.
  + Avoid implementation defined behaviour of shifts.
  + Start a test suite.
* Thu Mar 20 2014 dimstar@opensuse.org
- Update to version 1.14.30:
  + Activate translations for gsf (bgo#725409).
  + Fix invalid g_free for Windows.
  + Work around glib/gio bug (bgo#724970).
- Add pkgconfig(gdk-pixbuf-2.0) and libbz2-devel BuildRequires:
  Enable remaining features.
* Sun Jan  5 2014 dimstar@opensuse.org
- Update to version 1.14.29:
  + Fix problem with GsfOutfileStdio (bgo#706219).
  + Fix translation issue and leak (bgo#706937).
  + Fix fuzzed ods file crash (bgo#720458).
  + Updated translations.
- Drop libgsf-g_memmove-no-more.patch: fixed upstream.
* Thu Dec 19 2013 dimstar@opensuse.org
- Add libgsf-g_memmove-no-more.patch: g_memmove has been dropped.
* Fri Aug  2 2013 dimstar@opensuse.org
- Update to version 1.14.28:
  + Fix conversion specifiers (bgo#703064).
  + Allow the huge libxml parser mode so that gnumeric can load
    large images (bgo#705100).
  + Fix problem with bogus metadata (bgo#703952).
  + Avoid interaction problems between Werror and system headers.
* Sun Jun 23 2013 zaitor@opensuse.org
- Update to version 1.14.27:
  + Perform some range checking in
  + gsf_timestamp_load_from_string to avoid crashing in glib
    (bgo#702671).
  + Introspection fixes.
  + Property documentation fixes.
  + I18n fixes for property strings.
  + I18n fixes for error strings.
  + Fix uncompress problem with bzip'd files.
  + Add modtime support for GsfInput, GsfInputStdio, GsfInputGzip,
    GsfInfileZip, GsfInfileTar, GsfInfileMSOle, GsfOutput,
    GsfOutputStdio, GsfOutputGzip, GsfOutfileZip, GsfOutfileMSOle.
  + Enhance gsf tool to print modtime and create archives with
    modtime.
  + Improve handling of broken OLE2 files.
  + Plug leaks.
* Thu Feb 28 2013 dimstar@opensuse.org
- Update to version 1.14.26:
  + Fix vba stream problem (bgo#656531).
  + Make somewhat more robust with truncated files (bgo#690524).
  + Deal with G_TYPE_CHAR signedness.
  + Fix error handling of gsf_output_gio_new_for_uri.
  + Clean out mistaken null checks from g_object_new.
  + Clean out old glib tests.
  + Speed up ole writing a bit.
  + Header cleanup. gsf/gsf.h is now the main header (bgo#684608).
  + GsfInput doc improvements (bgo#540521).
  + Introspection fixes.
  + Fix gsf_input_dep for msole streams (bgo#689706).
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 1.14.25:
  + Enhance gsf tool to create archives.
  + Fix memory management problem with document properties.
  + Fix writing of OLE2 properties for multi-byte codepages
    (bgo#627696).
  + Unconditionally require gio (bgo#687753).
- Add pkgconfig(gio-2.0) BuildRequires: new dependency.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 1.14.24:
  + Fix namespace issues (bgo#672512)
  + Fix build after introspection implementation (bgo#673029).
- Pass --enable-introspection to configure: it's currently disabled
  by default.
* Wed Apr 25 2012 vuntz@opensuse.org
- Stop building python bindings, as we now have introspection
  support:
  + Remove python-devel, python-gobject2-devel, python-gtk-devel
    BuildRequires.
  + Add python-gsf Obsoletes to libgsf-1-114 subpackage, to smooth
    upgrades.
  + Do not pass --with-python to configure.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Fri Apr 20 2012 dimstar@opensuse.org
- Update to version 1.14.23:
  + Fix read/write of GSF_DOCPROP_VECTOR_TYPE meta data
    [Part of bgo#672716].
  + Add gobject introspection support. [bgo#610340]
  + OpenBSD portability fix.
  + Make introspection work when libgsf is not installed
    [bgo#671698]
  + Fix time stamp drift problem. [Part of bgo#671860]
  + New GsfODFOut class.
- Pass --with-python to configure. This was implicit before.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires: Add new
  gobject-introespection support.
- Split out typelib in typelib-1_0-Gsf-1 subpackage and require
  the new subpackage from the -devel package.
* Wed Dec 21 2011 vuntz@opensuse.org
- Remove gconf2-devel and libbonobo-devel BuildRequires: those were
  only needed for the gnome-vfs/bonobo support, which got removed
  in version 1.14.22.
- Move thumbnailer out in a gsf-office-thumbnailer subpackage, so
  we can install it by default.
- Rename main subpackage to libgsf-tools, as it only contains tools
  that are not of high interest to most users.
- Create lang subpackage.
- Add libgsf Provides to libgsf-1-114 to make lang subpackage
  installable.
- Add lang subpackage Recommends to libgsf-1-114.
- Rewrite summaries and descriptions, with more accurate text.
- Change group of all packages to be more accurate, instead of
  Development/Libraries/GNOME:
  + use System/Libraries for libgsf-1-114
  + use Productivity/Office/Other for tools and
    gsf-office-thumbnailer subpackages
  + keep Development/Libraries/GNOME for devel subpackage
  + use Development/Libraries/Python for python-gsf
* Fri Dec 16 2011 dimstar@opensuse.org
- Update to version 1.14.22:
  + Fix thumbnailer manual install problem.
  + Fix error messages on win32.
  + Fix resource limiting in thumbnailer.
  + Ensure GsfOutput::name and GsfInput::name notifications.
  + Cleanup old code.
  + Drop support for gnome-vfs and bonobo.
  + Fix ole2 entry sorting. [bgo#665712]
  + New installation method for thumbnailer. [bgo#651187]
- Drop gnome subpackage:
  - As gnome-vfs and bonobo support was dropped, there are no more
    files in this package.
  - Add Obsoletes for libgsf-gnome < 1.14.22 to libgsf-1-114, to
    ease upgrades.
  - Remove libgsf-gnome Requires from devel subpackage.
  - Remove gconf schema handling.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Change glib2-devel and libxml2-devel BuildRequires to
  pkgconfig(glib-2.0) and pkgconfig(libxml-2.0).
- Clean spec-file using spec-cleaner.
* Sat May 21 2011 dimstar@opensuse.org
- Update to version 1.14.21:
  + bgo#645775: Implement --without-gconf for explicit dependency
    control.
  + bgo#645778: Fix python compilation problem.
  + bgo#649827: Fix crash on encountering user defined meta data of
    default type.
  + Write/read the correct attribute name for the value-type of
    user defined meta-data.
  + Move ODF version to 1.2.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to version 1.14.20:
  + Fix msole reading crash.
  + bgo#644217: Improve loading on metadata.
* Mon Sep 27 2010 vuntz@opensuse.org
- Remove explicit Requires in devel package: they will
  automatically be added the pkgconfig()-way, or they were wrong
  (bzip2 and zlib-devel).
* Sun Sep 26 2010 vuntz@opensuse.org
- Update to version 1.14.19:
  + Add some more OOo 3.2 and 3.3 namespaces.
  + Quiet xml parsing two bits.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Thu Apr  8 2010 vuntz@opensuse.org
- Update to version 1.14.18:
  + Fix zip directory record problem. [bgo#614968]
* Sun Feb 14 2010 vuntz@opensuse.org
- Update to version 1.14.17:
  + Fix xml parser crash.
  + Write meta-data values in name order.
  + Don't call gnome_vfs_init in python binding. [bgo#599973]
* Thu Dec 17 2009 jengelh@medozas.de
- Add baselibs.conf as a source
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 1.14.16:
  + Add variant of OO_NS_FIELD.
  + Use gdk_pixbug for thumbnailing when available.  [bgo#594359]
  + Fix problem with errors to stdout.  [bgo#592471]
  + Fix gnome-vfs dependency handling.  [bgo#593480]
- Drop libgsf-fix-configure.patch: fixed upstream.
- Drop gnome-common BuildRequires, and remove gnome-autogen.sh
  call.
- Fix rpmlint warnings about self-obsoletion of doc package.
* Sun Aug 30 2009 vuntz@novell.com
- Use python_sitearch and python_sitelib: both are needed for the
  python files.
* Sat Aug 29 2009 vuntz@novell.com
- Change libgnome-devel BuildRequires to libbonobo-devel.
- Add python-gobject2-devel and python-gtk-devel BuildRequires.
  This allows us to build the python bindings, so we create a
  python-gsf package.
- Add libgsf-fix-configure.patch to not uselessly require gnome-vfs
  for the build. Add gnome-common and call gnome-autogen.sh for the
  patch.
- Fix requires of subpackages to require libgsf1-114, and not
  libgsf.
- Merge doc package in devel package, and have the devel package
  provide/obsolete it.
* Mon Jun 22 2009 dominique-obs@leuenberger.net
- Update to version 1.14.15:
  + Bump ODF version to 1.1 and add enum to inform users
  + Fix criticals when parsing bogus OLE properties, bgo#584848
  + Start cleaning up timestamp code.
* Sun May 24 2009 vuntz@novell.com
- Update to version 1.14.14:
  + Added namespaces used by openoffice 3.0, Lotus Symphony, etc.
  + Fix gsf_xml_out_start_element to allow child elements mixed
    with other content
* Thu May  7 2009 vuntz@novell.com
- Update to version 1.14.13:
  + Fix gsf_opendoc_metadata_subtree [bgo#581530]
* Mon Apr 27 2009 vuntz@novell.com
- Update to version 1.14.12:
  + Also read user defined OpenDocument metadata
  + Fix allocation method problem. [bgo#579155]
  + Fix incorrect use of g_enum_register_static which broke
    documentation generation in some environments.
  + Handle small-block files that are not block aligned.
    [bgo#572290]
  + Deprecate gsf_timestamp_parse and replace it with
    gsf_timestamp_from_string.
  + Gtk-Doc fixes.
  + Fix handling of namespace declared default and prefix. (Such as
    in SpreadsheetML-2003)
  + Handle malformed xml better. [bgo#568994]
  + Drop characters that xml 1.0 cannot represent.  [bgo#568919]
  + Fix problem loading zero-sized files.  [bgo#580228]
- Remove unneeded BuildRequires: gnome-common, gtk-doc.
- Remove AutoReqProv: it's default now.
- Use makeinstall.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Jan 23 2009 vuntz@novell.com
- Merge openSUSE:Factory & GNOME:Factory:Next.
- Clean up spec file, removing tests for old versions.
* Sat Jan 17 2009 crrodriguez@suse.de
- remove la files.
* Thu Jan  8 2009 mboman@suse.de
- Update to version 1.14.11:
  + win32 build fix for glib-2.18 deprecation.
  + Extend MS Office Open Pkg handling to accept POI files.
  + Add libxml2 wrapper to simplify probing.
  + Solaris compilation issue. [bgo#558253]
  + Handle non-seekable files in gsf_input_stdio_new. [bgo#154417]
  + Fix various Mac compilation issues. [bgo#565603], [bgo#565605]
  + Clean up glib includes. [bgo#564004]
  + MinGW configure fix for libbz2 detection.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Dec 29 2008 mboman@suse.de
- Update to version 1.14.10:
  + Patch some coverity issues [189, 250, 251]
  + Work around sshfs bug [bgo#509883]
  + Support tar archives
  + Improve gsf support for broken archives [bgo#553861]
  + Avoid a critical for bad ole2 [bgo#554848]
* Mon Sep  1 2008 mboman@novell.com
- Update to version 1.14.9:
  + Revitalize gio support.
  + Add MS OOX support to gsf-vba-dump.
  + Extend the utility wrappers for GsfInfile.
  + Be more forgiving of corrupt ole2.
  + Add additional MS OpenPkg support to facilitate pivots.
  + gtk-doc improvements.
  + Make the VBA extractor more accessible.
  + Extensions for the xml parser to allow modularization.
  + Use g_base64_-routines from glib when available.
  + When gio is available, do not link in gnomevfs.
  + Add self-check for the benefit of __arm__.
- Removed libgsf-fate303676.patch. Fixed upstream.
* Tue Jul 29 2008 hfiguiere@suse.de
- add libgsf-fate303676.patch to implement MS Office Open XML
  thumbnailing (FATE#303676)
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  2 2008 rodrigo@suse.de
- Update to version 1.14.8:
  * Add missing ODF presentation message
  * Only install win32 header for win32 (bgo#459771)
  * Fix XML enum export utils
  * Fix criticals for corrupted file (bgo#485964)
  * Improve sanity checks of ole properties (bgo#404934)
  * Enhance gsf (the program) to list all document properites
  * Fix endless loop with broken ole files (bgo#513831)
  * Fix memory allocation problem due to broken ole files
* Mon Feb 18 2008 maw@suse.de
- Update to version 1.14.7:
  + Add some safety checks for out of memory conditions
  + Some extensions to simplifiy OOX export
  + Improved docs.
* Sat Nov 17 2007 dmueller@suse.de
- break dependency loop by removing unneeded requires
* Wed Oct  3 2007 maw@suse.de
- Split out a libgsf-1-114 subpackage.
* Fri Aug  3 2007 jpr@suse.de
- Update to 1.14.5
- Revert jump to dynamic types, they aren't threadsafe. (BGO #450722)
- Compilation glitch on windows.  (BGO #449807)
- Avoid problems building without gconf macros installed.
- Configure breakage --without-gnome. (BGO #4488842)
- Make Bonobo support optional. (BGO #442205]
- Limit resource usage in the thumbnailer. (BGO #446087)
- Have gsf-vba-dump handle .doc files too.
- Implement gsf_init_dynamic
- Tidy up docs and #includes in public headers.
- Move the MS/ECMA Open Package code here from gnumeric.
- Provide a libxml2-nanohttp wrapper. (BGO #362373)
- Plug leak.
- Fix potential problem with reading mildly bogus files.  (BGO #381588)
- Fix potential oom crash on crazy OLE2 files.  (BGO #381600)
- Quote csv fields on initial or terminal white-space.  (BGO #359348)
- Fix encoding problem with thumbnailer.
- Fix problem with gsf_output_printf triggering on x64_86.
- Handle nested xml contents.
- Basic life support for python bindings.  (BGO #382239] (BGO #382254)
- Fix crash exporting keyword vector from OLE2 -> ODF.
- Improve debug spew for OLE2 propert import.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Thu Dec 14 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Dec 14 2006 sbrabec@suse.cz
- Fixed old soname support for released products.
* Sun Oct 15 2006 danw@suse.de
- Remove upstreamed patches
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 1.14.2
- Fix export of msole2 double(r8) properties
- removed upstreamed patches
- Add metadata property dump function to gsf command
- Improve ms-ole property sanity checking
- Initial variant of a gsf based tar like utility
- many bug fixes
* Thu Jun  8 2006 jody@suse.de
- Add more mime types for OOo 1.0 thumbnailing
- enable the vba dump utility to facilitate bug reports
- back port some of the fixes in 1.14.1
* Fri Mar  3 2006 jpr@suse.de
- Ensure no transparent backgrounds
- Tweak OO meta data
* Thu Mar  2 2006 jpr@suse.de
- Enable the thumbnailers
* Thu Mar  2 2006 jpr@suse.de
- Update to 1.13.99
- thumbnailing for OO docs fixes #153130
- other changes:
  * Initial Swedish PO translation. [Debian #351382]
  * Only export symbols which are in the public headers (Win32).
  * Fix parsing xml files with &amp;
  * bump to 1.14.0 to indicate a stable release.
  * improve header versioning.
  * Add ODF thumbnail support to gsf-office-thumbnailer
  * Enable ODF meta data import/export.
  * Fix GsfOutputIConv.  [#323503]
  * Plug leak in GsfInfileZip.
* Sat Feb  4 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 21 2005 stbinner@suse.de
- add workaround for PLUS so that not all applications break if a
  user updates libgsf because an applications built against it
* Wed Nov 16 2005 sbrabec@suse.cz
- Updated to version 1.13.3.
* Thu Nov  3 2005 sbrabec@suse.cz
- Updated to version 1.13.2.
* Tue Nov  1 2005 federico@novell.com
- Added libgsf-thumbnail-support.diff, backported from CVS HEAD.  This makes libgsf support
  the VT_CF summary property in OLE files, used to store file thumbnails.  It also adds
  a gsf-office-thumbnailer program that plugs into the GNOME thumbnailing infrastructure.
* Wed Aug  3 2005 gekker@suse.de
- Update to version 1.12.1
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Tue Dec  7 2004 jody@suse.de
- Update to version 1.11.1
- Fix OLE2 import problems
- Enable OLE2 property sets for beagle
* Fri Aug 20 2004 jody@suse.de
- Updated to version 1.10.1
- Fixed major that would cause Ms Excel to corrupt files larger
  than 6.8 Meg in transation mode
* Fri May  7 2004 clahey@suse.de
- Updated to version 1.9.0.
* Tue Apr 27 2004 ro@suse.de
- add -fno-strict-aliasing
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr and %%run_ldconfig
* Tue Oct  7 2003 sbrabec@suse.cz
- Updated to version 1.8.2.
* Wed Jul 23 2003 hhetter@suse.de
- fix documentation packaging
- use gnome-filesystem
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Mon Jun 30 2003 ro@suse.de
- move documentation to /usr/share/gtk-doc
* Mon Jun  9 2003 sbrabec@suse.cz
- Updated to version 1.8.1.
* Wed Jun  4 2003 sbrabec@suse.cz
- Updated to version 1.8.0.
- Use gnome2-devel-packages in neededforbuild.
* Sun Jun  1 2003 ro@suse.de
- added doc filelist to specfile
* Sun Apr 27 2003 adrian@suse.de
- put libgsf-gnome into new sub package libgsf-gnome
* Tue Apr  8 2003 adrian@suse.de
- update to version 1.7.2
* Sun Mar  2 2003 meissner@suse.de
- removed cdparanoia neededforbuild requires
- fixed implicit function references (strcmp,strlen,memcmp,time)
* Thu Jan 23 2003 meissner@suse.de
- lib -> %%_lib in filelist.
* Mon Jan 13 2003 hhetter@suse.de
- initial SuSE package
